GOparser
========

A Python framework for working with gene ontology (GO) terms and annotations.

If you use GOparser, please cite `Wagner (2015) <http://dx.doi.org/10.1101/018705>`_.

Installation
------------

.. code-block:: bash

    $ pip install goparser

Documentation
-------------

In the works!

Copyright and License
---------------------

Copyright (c) 2015 Florian Wagner

::

  GOparser is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License, Version 3,
  as published by the Free Software Foundation.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
